@@ -6,6 +6,7 @@ import (
 	"errors"
 	"time"
 
+	. "github.com/onsi/ginkgo/v2"
 	. "github.com/onsi/gomega"
 )
 
@@ -78,3 +79,11 @@ func WrongEventuallyWithFunction_nil() {
 	Eventually(slowInt_nil).Should(Equal(42))   // valid
 	Eventually(slowInt_nil()).Should(Equal(42)) // want "ginkgo-linter: use a function call in Eventually. This actually checks nothing, because Eventually receives the function returned value, instead of function itself, and this value is never changed; consider using .Eventually\\(slowInt_nil\\)\\.Should\\(Equal\\(42\\)\\). instead"
 }
+
+var _ = FDescribe("Should warn for focused containers", func() {
+	FContext("should not allow FContext", func() {
+		FWhen("should not allow FWhen", func() {
+			FIt("should not allow FIt", func() {})
+		})
+	})
+})
